@@ -4,6 +4,7 @@
 #endif
 
 #include <QApplication>
+#include <QDir>
 #include <QTranslator>
 
 /*! \mainpage QtPass
@@ -18,7 +19,7 @@
  *
  * \subsection dependencies Dependencies
  *
- * - QtPass requires Qt 4.8 or later, preferably Qt5.5 or later.
+ * - QtPass requires Qt 5.2 or later.
  * - The Linguist package is required to compile the translations.
  * - For use of the fallback icons the SVG library is required.
  *
@@ -39,7 +40,9 @@
  * @return
  */
 int main(int argc, char *argv[]) {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
   QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
   QString text = "";
   for (int i = 1; i < argc; ++i) {
     if (i > 1)
@@ -65,6 +68,8 @@ int main(int argc, char *argv[]) {
   QApplication app(argc, argv);
 #endif
 
+  Q_INIT_RESOURCE(resources);
+
   QCoreApplication::setOrganizationName("IJHack");
   QCoreApplication::setOrganizationDomain("ijhack.org");
   QCoreApplication::setApplicationName("QtPass");
@@ -77,21 +82,24 @@ int main(int argc, char *argv[]) {
   // locale = "he_IL";
   // locale = "ar_MA";
   translator.load(QString(":localization/localization_%1.qm").arg(locale));
-  app.installTranslator(&translator);
-  app.setLayoutDirection(QObject::tr("LTR") == "RTL" ? Qt::RightToLeft
-                                                     : Qt::LeftToRight);
+  SingleApplication::installTranslator(&translator);
+  SingleApplication::setLayoutDirection(
+      QObject::tr("LTR") == "RTL" ? Qt::RightToLeft : Qt::LeftToRight);
   MainWindow w(text);
 
-  app.setActiveWindow(&w);
-  app.setWindowIcon(QIcon(":artwork/icon.png"));
+  SingleApplication::setActiveWindow(&w);
+  SingleApplication::setWindowIcon(QIcon(":artwork/icon.png"));
 
-  QObject::connect(&app, SIGNAL(aboutToQuit()), &w, SLOT(clearClipboard()));
 #if SINGLE_APP
-  QObject::connect(&app, SIGNAL(messageAvailable(QString)), &w,
-                   SLOT(messageAvailable(QString)));
+  QObject::connect(&app, &SingleApplication::messageAvailable, &w,
+                   &MainWindow::messageAvailable);
+#endif
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0))
+  QGuiApplication::setDesktopFileName("qtpass.desktop");
 #endif
 
   w.show();
 
-  return app.exec();
+  return SingleApplication::exec();
 }
