@@ -30,8 +30,10 @@ enum PROCESS {
   GIT_MOVE,
   GIT_COPY,
   PROCESS_COUNT,
-  INVALID
+  INVALID,
+  PASS_OTP_GENERATE,
 };
-}
+
+} // namespace Enums
 
 #endif // ENUMS_H
