@@ -1,8 +1,6 @@
 #ifndef KEYGENDIALOG_H_
 #define KEYGENDIALOG_H_
 
-#include "configdialog.h"
-#include <QCloseEvent>
 #include <QDialog>
 
 namespace Ui {
@@ -13,6 +11,8 @@ class KeygenDialog;
     \class KeygenDialog
     \brief Handles GPG keypair generation.
  */
+class ConfigDialog;
+class QCloseEvent;
 class KeygenDialog : public QDialog {
   Q_OBJECT
 
@@ -32,7 +32,7 @@ private slots:
 
 private:
   Ui::KeygenDialog *ui;
-  void replace(QString, QString);
+  void replace(const QString &, const QString &);
   void done(int r);
   void no_protection(bool enable);
   ConfigDialog *dialog;
