@@ -1,8 +1,11 @@
 #include "pass.h"
-#include "debughelper.h"
 #include "qtpasssettings.h"
 #include "util.h"
 
+#ifdef QT_DEBUG
+#include "debughelper.h"
+#endif
+
 using namespace std;
 using namespace Enums;
 
@@ -20,6 +23,7 @@ Pass::Pass() : wrapperRunning(false), env(QProcess::systemEnvironment()) {
   //        SIGNAL(error(QProcess::ProcessError)));
 
   connect(&exec, &Executor::starting, this, &Pass::startingExecuteWrapper);
+  env.append("WSLENV=PASSWORD_STORE_DIR/p");
 }
 
 void Pass::executeWrapper(PROCESS id, const QString &app,
@@ -31,7 +35,9 @@ void Pass::executeWrapper(PROCESS id, const QString &app,
 void Pass::executeWrapper(PROCESS id, const QString &app,
                           const QStringList &args, QString input,
                           bool readStdout, bool readStderr) {
+#ifdef QT_DEBUG
   dbg() << app << args;
+#endif
   exec.execute(id, QtPassSettings::getPassStore(), app, args, input, readStdout,
                readStderr);
 }
@@ -66,7 +72,7 @@ QString Pass::Generate_b(unsigned int length, const QString &charset) {
     // --secure goes first as it overrides --no-* otherwise
     QStringList args;
     args.append("-1");
-    if (QtPassSettings::isLessRandom())
+    if (!QtPassSettings::isLessRandom())
       args.append("--secure");
     args.append(QtPassSettings::isAvoidCapitals() ? "--no-capitalize"
                                                   : "--capitalize");
@@ -82,8 +88,10 @@ QString Pass::Generate_b(unsigned int length, const QString &charset) {
       passwd.remove(QRegExp("[\\n\\r]"));
     else {
       passwd.clear();
+#ifdef QT_DEBUG
       qDebug() << __FILE__ << ":" << __LINE__ << "\t"
                << "pwgen fail";
+#endif
       //    TODO(bezet): emit critical ?
     }
   } else {
@@ -113,16 +121,20 @@ void Pass::GenerateGPGKeys(QString batch) {
 
 /**
  * @brief Pass::listKeys list users
- * @param keystring
+ * @param keystrings
  * @param secret list private keys
  * @return QList<UserInfo> users
  */
-QList<UserInfo> Pass::listKeys(QString keystring, bool secret) {
+QList<UserInfo> Pass::listKeys(QStringList keystrings, bool secret) {
   QList<UserInfo> users;
-  QStringList args = {"--no-tty", "--with-colons"};
+  QStringList args = {"--no-tty", "--with-colons", "--with-fingerprint"};
   args.append(secret ? "--list-secret-keys" : "--list-keys");
-  if (!keystring.isEmpty())
-    args.append(keystring);
+
+  foreach (QString keystring, keystrings) {
+    if (!keystring.isEmpty()) {
+      args.append(keystring);
+    }
+  }
   QString p_out;
   if (exec.executeBlocking(QtPassSettings::getGpgExecutable(), args, &p_out) !=
       0)
@@ -144,6 +156,8 @@ QList<UserInfo> Pass::listKeys(QString keystring, bool secret) {
       current_user.expiry.setTime_t(props[6].toUInt());
     } else if (current_user.name.isEmpty() && props[0] == "uid") {
       current_user.name = props[9];
+    } else if ((props[0] == "fpr") && props[9].endsWith(current_user.key_id)) {
+      current_user.key_id = props[9];
     }
   }
   if (!current_user.key_id.isEmpty())
@@ -151,6 +165,16 @@ QList<UserInfo> Pass::listKeys(QString keystring, bool secret) {
   return users;
 }
 
+/**
+ * @brief Pass::listKeys list users
+ * @param keystring
+ * @param secret list private keys
+ * @return QList<UserInfo> users
+ */
+QList<UserInfo> Pass::listKeys(QString keystring, bool secret) {
+  return listKeys(QStringList(keystring), secret);
+}
+
 /**
  * @brief Pass::processFinished reemits specific signal based on what process
  * has finished
@@ -163,7 +187,7 @@ QList<UserInfo> Pass::listKeys(QString keystring, bool secret) {
  */
 void Pass::finished(int id, int exitCode, const QString &out,
                     const QString &err) {
-  PROCESS pid = static_cast<PROCESS>(id);
+  auto pid = static_cast<PROCESS>(id);
   if (exitCode != 0) {
     emit processErrorExit(exitCode, err);
     return;
@@ -200,7 +224,9 @@ void Pass::finished(int id, int exitCode, const QString &out,
     emit finishedCopy(out, err);
     break;
   default:
+#ifdef QT_DEBUG
     dbg() << "Unhandled process type" << pid;
+#endif
     break;
   }
 }
@@ -210,7 +236,7 @@ void Pass::finished(int id, int exitCode, const QString &out,
  * switching profiles)
  */
 void Pass::updateEnv() {
-  QStringList store = env.filter("PASSWORD_STORE_DIR");
+  QStringList store = env.filter("PASSWORD_STORE_DIR=");
   // put PASSWORD_STORE_DIR in env
   if (store.isEmpty()) {
     // dbg()<< "Added
@@ -266,15 +292,11 @@ QStringList Pass::getRecipientList(QString for_file) {
  * @param count
  * @return recepient string
  */
-QString Pass::getRecipientString(QString for_file, QString separator,
-                                 int *count) {
-  QString recipients_str;
-  QStringList recipients_list = Pass::getRecipientList(for_file);
-  if (count)
-    *count = recipients_list.size();
-  foreach (const QString recipient, recipients_list)
-    recipients_str += separator + '"' + recipient + '"';
-  return recipients_str;
+QStringList Pass::getRecipientString(QString for_file, QString separator,
+                                     int *count) {
+  Q_UNUSED(separator)
+  Q_UNUSED(count)
+  return Pass::getRecipientList(for_file);
 }
 
 /* Copyright (C) 2017 Jason A. Donenfeld <Jason@zx2c4.com>. All Rights Reserved.
