@@ -1,6 +1,6 @@
 #include "passworddialog.h"
-#include "debughelper.h"
 #include "filecontent.h"
+#include "pass.h"
 #include "passwordconfiguration.h"
 #include "qtpasssettings.h"
 #include "ui_passworddialog.h"
@@ -8,6 +8,10 @@
 #include <QLabel>
 #include <QLineEdit>
 
+#ifdef QT_DEBUG
+#include "debughelper.h"
+#endif
+
 /**
  * @brief PasswordDialog::PasswordDialog basic constructor.
  * @param passConfig configuration constant
@@ -23,14 +27,16 @@ PasswordDialog::PasswordDialog(const PasswordConfiguration &passConfig,
   ui->setupUi(this);
   setLength(m_passConfig.length);
   setPasswordCharTemplate(m_passConfig.selected);
+
+  connect(QtPassSettings::getPass(), &Pass::finishedShow, this,
+          &PasswordDialog::setPass);
 }
 
 /**
  * @brief PasswordDialog::PasswordDialog complete constructor.
- * @param passConfig configuration constant
  * @param file
  * @param isNew
- * @param parent
+ * @param parent pointer
  */
 PasswordDialog::PasswordDialog(const QString &file, const bool &isNew,
                                QWidget *parent)
@@ -52,6 +58,8 @@ PasswordDialog::PasswordDialog(const QString &file, const bool &isNew,
   setLength(m_passConfig.length);
   setPasswordCharTemplate(m_passConfig.selected);
 
+  connect(QtPassSettings::getPass(), &Pass::finishedShow, this,
+          &PasswordDialog::setPass);
   connect(QtPassSettings::getPass(), &Pass::processErrorExit, this,
           &PasswordDialog::close);
   connect(this, &PasswordDialog::accepted, this, &PasswordDialog::on_accepted);
@@ -59,7 +67,7 @@ PasswordDialog::PasswordDialog(const QString &file, const bool &isNew,
 }
 
 /**
- * @brief PasswordDialog::~PasswordDialog basic destructor.
+ * @brief Pass{}{}wordDialog::~PasswordDialog basic destructor.
  */
 PasswordDialog::~PasswordDialog() { delete ui; }
 
@@ -128,7 +136,7 @@ void PasswordDialog::setPassword(QString password) {
   // show remaining values (if there are)
   otherLines.clear();
   for (const NamedValue &nv : namedValues) {
-    QLineEdit *line = new QLineEdit();
+    auto *line = new QLineEdit();
     line->setObjectName(nv.name);
     line->setText(nv.value);
     ui->formLayout->addRow(new QLabel(nv.name), line);
@@ -173,7 +181,7 @@ void PasswordDialog::setTemplate(QString rawFields, bool useTemplate) {
     foreach (QString field, m_fields) {
       if (field.isEmpty())
         continue;
-      QLineEdit *line = new QLineEdit();
+      auto *line = new QLineEdit();
       line->setObjectName(field);
       ui->formLayout->addRow(new QLabel(field), line);
       setTabOrder(previous, line);
