@@ -22,8 +22,9 @@ class PasswordDialog : public QDialog {
 
 public:
   explicit PasswordDialog(const PasswordConfiguration &passConfig,
-                          QWidget *parent = 0);
-  PasswordDialog(const QString &file, const bool &isNew, QWidget *parent = 0);
+                          QWidget *parent = nullptr);
+  PasswordDialog(const QString &file, const bool &isNew,
+                 QWidget *parent = nullptr);
   ~PasswordDialog();
 
   /*! Sets content in the password field in the interface.
