@@ -1,5 +1,4 @@
 #include "util.h"
-#include "debughelper.h"
 #include <QDir>
 #include <QFileInfo>
 #ifdef Q_OS_WIN
@@ -8,6 +7,11 @@
 #include <sys/time.h>
 #endif
 #include "qtpasssettings.h"
+
+#ifdef QT_DEBUG
+#include "debughelper.h"
+#endif
+
 QProcessEnvironment Util::_env;
 bool Util::_envInitialised;
 
@@ -99,7 +103,6 @@ QString Util::findBinaryInPath(QString binary) {
         qfi.reset(new QFileInfo(entry.append(".exe")));
 
 #endif
-      dbg() << entry;
       if (!qfi->isExecutable())
         continue;
 
@@ -107,6 +110,16 @@ QString Util::findBinaryInPath(QString binary) {
       break;
     }
   }
+#ifdef Q_OS_WIN
+  if (ret.isEmpty()) {
+    binary.remove(0, 1);
+    binary.prepend("wsl ");
+    QString out, err;
+    if (Executor::executeBlocking(binary, {"--version"}, &out, &err) == 0 &&
+        !out.isEmpty() && err.isEmpty())
+      ret = binary;
+  }
+#endif
 
   return ret;
 }
@@ -118,8 +131,11 @@ QString Util::findBinaryInPath(QString binary) {
 bool Util::checkConfig() {
   return !QFile(QDir(QtPassSettings::getPassStore()).filePath(".gpg-id"))
               .exists() ||
-         (!QFile(QtPassSettings::getPassExecutable()).exists() &&
-          !QFile(QtPassSettings::getGpgExecutable()).exists());
+         (QtPassSettings::isUsePass()
+              ? !QtPassSettings::getPassExecutable().startsWith("wsl ") &&
+                    !QFile(QtPassSettings::getPassExecutable()).exists()
+              : !QtPassSettings::getGpgExecutable().startsWith("wsl ") &&
+                    !QFile(QtPassSettings::getGpgExecutable()).exists());
 }
 
 /**
@@ -133,7 +149,8 @@ bool Util::checkConfig() {
 QString Util::getDir(const QModelIndex &index, bool forPass,
                      const QFileSystemModel &model,
                      const StoreModel &storeModel) {
-  QString abspath = QDir(QtPassSettings::getPassStore()).absolutePath() + '/';
+  QString abspath =
+      QDir(QtPassSettings::getPassStore()).absolutePath() + QDir::separator();
   if (!index.isValid())
     return forPass ? "" : abspath;
   QFileInfo info = model.fileInfo(storeModel.mapToSource(index));
@@ -142,13 +159,13 @@ QString Util::getDir(const QModelIndex &index, bool forPass,
   if (forPass) {
     filePath = QDir(abspath).relativeFilePath(filePath);
   }
-  filePath += '/';
+  filePath += QDir::separator();
   return filePath;
 }
 
-void Util::copyDir(const QString src, const QString dest) {
+void Util::copyDir(const QString &src, const QString &dest) {
   QDir srcDir(src);
-  if (srcDir.exists() == false) {
+  if (!srcDir.exists()) {
     return;
   }
   srcDir.mkpath(dest);
