@@ -21,7 +21,7 @@ public:
   static QString getDir(const QModelIndex &index, bool forPass,
                         const QFileSystemModel &model,
                         const StoreModel &storeModel);
-  static void copyDir(const QString src, const QString dest);
+  static void copyDir(const QString &src, const QString &dest);
 
 private:
   static void initialiseEnvironment();
